Picomotor - Heros Devices 0.11.1 documentation

Skip to content
Back to top
View this page

# Picomotor

From: Newport

Class: `herosdevices.hardware.newport.picomotor.Picomotor`

Driver Quality Index: alpha

HEROS driver for a single Picomotor.

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.newport.picomotor.Picomotor` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
controller | <class ‘herosdevices.hardware.newport.picomotor.PicomotorController8742’> |  | RemoteHERO of the controller the motor is attached to.
axis | <class ‘int’> |  | port of the controller. Available axes are 1,2,3,4.

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `Picomotor` using BOSS.

    {
        "_id": "my_Picomotor",
        "classname": "herosdevices.hardware.newport.picomotor.Picomotor",
        "arguments": {
            "controller": "<class 'herosdevices.hardware.newport.picomotor.PicomotorController8742'>",
            "axis": "<class 'int'>"
        }
    }

generated from signature

Inheritance